@@ -21,6 +21,7 @@
 
 #include <config.h>
 #include <stdint.h>
+#include "pvm-program-point.h"
 
 /* The least-significative bits of pvm_val are reserved for the tag,
    which specifies the type of the value.  */
@@ -500,12 +501,13 @@ typedef struct pvm_type *pvm_type;
 #define PVM_VAL_CLS_ENTRY_POINT(V) (PVM_VAL_CLS((V))->entry_point)
 #define PVM_VAL_CLS_ENV(V) (PVM_VAL_CLS((V))->env)
 
-typedef struct pvm_program *pvm_program;
-typedef void *pvm_program_program_point;
+/* A struct containing a PVM program.
+   Defined elsewhere.  */
+struct pvm_program;
 
 struct pvm_cls
 {
-  pvm_program program;
+  struct pvm_program *program;
   pvm_program_program_point entry_point;
   struct pvm_env *env;
 };
@@ -529,14 +531,14 @@ typedef struct pvm_cls *pvm_cls;
 #define PVM_VAL_OFF_UNIT_MEGABITS (1000 * PVM_VAL_OFF_UNIT_KILOBITS)
 #define PVM_VAL_OFF_UNIT_MEGABYTES (1000 * PVM_VAL_OFF_UNIT_KILOBYTES)
 #define PVM_VAL_OFF_UNIT_GIGABITS (1000 * PVM_VAL_OFF_UNIT_MEGABITS)
-#define PVM_VAL_OFF_UNIT_GIGABYTES (1000LU * PVM_VAL_OFF_UNIT_MEGABYTES)
+#define PVM_VAL_OFF_UNIT_GIGABYTES (((uint64_t) 1000LU) * PVM_VAL_OFF_UNIT_MEGABYTES)
 
 #define PVM_VAL_OFF_UNIT_KIBIBITS (1024 * PVM_VAL_OFF_UNIT_BITS)
 #define PVM_VAL_OFF_UNIT_KIBIBYTES (1024 * PVM_VAL_OFF_UNIT_BYTES)
 #define PVM_VAL_OFF_UNIT_MEBIBITS (1024 * PVM_VAL_OFF_UNIT_KIBIBITS)
 #define PVM_VAL_OFF_UNIT_MEBIBYTES (1024 * PVM_VAL_OFF_UNIT_KIBIBYTES)
 #define PVM_VAL_OFF_UNIT_GIGIBITS (1024 * PVM_VAL_OFF_UNIT_MEBIBITS)
-#define PVM_VAL_OFF_UNIT_GIGIBYTES (1024LU * PVM_VAL_OFF_UNIT_MEBIBYTES)
+#define PVM_VAL_OFF_UNIT_GIGIBYTES (((uint64_t) 1024) * PVM_VAL_OFF_UNIT_MEBIBYTES)
 
 struct pvm_off
 {
