@@ -25,11 +25,11 @@
 #include "pk-map.h"
 
 int
-pk_open_ios (const char *handler, int set_cur_p)
+pk_open_file (const char *handler, int set_cur_p)
 {
   int ios_id;
 
-  ios_id = pk_ios_open (poke_compiler, handler, 0, 1);
+  ios_id = pk_ios_open (poke_compiler, handler, 0, set_cur_p);
   if (ios_id == PK_IOS_NOID)
     return ios_id;
 
